---
title: "Lynne Teaches Tech: What do all the components of a computer mean?"
author: Lynne
categories: [Lynne Teaches Tech, Originally from the Fediverse]
tags: [Lynne Teaches Tech]
---

*This is a revised version of* [*this post*](https://fedi.lynnesbian.space/@lynnesbian/101544435256951090)*.*

If you're buying a computer or laptop or even a phone, there's a lot of jargon that might confuse you to look out for. It ranges from straightforward statistics to obscure facts to annoying "gotcha"s. This post aims to break them down.

<!--more-->  
The Fundamentals
----------------

### CPU

The central processing unit. This is what your computer uses to crunch numbers, and the benefits of a fast CPU can be seen everywhere from decompressing a large zip file to processing a heavy webpage to converting an AVI to an MP4. A slow CPU can make an otherwise good computer into a laggy, unresponsive mess.

We measure CPU performance in terms of instructions per second and cores. Instructions per second are measured in hertz, for example, 3.2GHz. One hertz is one instruction per second, so a 4KHz CPU can complete four thousand instructions per second. Instructions are very, very basic steps for a computer to do - think "add two numbers", not "open this file". The more instructions your computer can do per second, the faster it'll be.

Cores represent how many tasks your computer can work on at once. For example, if your video editor is using 100% CPU on your single-core machine, your computer will be unusable, but if you have more cores, you'll still have spare power, even when one of the cores is maxed out. Many modern apps, such as Chrome and Discord, take advantage of multiple cores by dedicating groups of tabs to each core.

"Hyperthreading" is an Intel technology that allows a CPU to act like it has more cores than it actually has, for example, a quad-core CPU with hyperthreading would be used as if it was an octo-core. The way this works is kinda complex, and I don't want to make this post too long.

### RAM

Also called memory, and not the same thing as storage. Memory is a measure of how much stuff your computer can do at once. When you open a document, picture, video, song, etc., some or all of it is loaded into memory. This is because memory is much, much faster than a hard drive or SSD. If you don't have enough memory, Windows (or macOS, or what have you) will start chugging along and apps will start crashing as they all fight over the scraps. You can mitigate this somewhat by creating a swap file on your hard drive, which will be used as supplementary memory, but then you lose the speed benefits, and waste storage space.

### Storage

HDD, SSD, SSHD, hybrid drive, hard drive, hard disk, solid state drive, Optane… All of these mean the same thing: storage. The more storage you have, the more files you can save. If you run out of storage, things start going badly, as your computer always needs a little spare storage to work with. Everything you download or install or save uses storage space.

So why are there all these different names? As technology marches on, we invent better methods for doing things, including storage. Hard drives are slow and inefficient (they're one of the few parts of a modern computer that are still mechanical), but much cheaper than SSDs. SSDs work like a flash drive (aka usb stick, thumb drive…) and thus avoid the speed issues of a conventional hard drive. Hard drives need to be defragmented because as you create and delete files, they get ordered poorly, and it takes longer to access them, because the magnetic platter needs to spin more for the needle to read the files (yes, this is actually how hard drives work). With an SSD, however, there's no needle or platter, and files can be accessed "out of order" much more easily.

One caveat: you might have noticed that when you buy an 8GB flash drive, it's not actually 8GB. This is because there are two definitions of a gigabyte (and a megabyte, and a kilobyte…) - 1000 megabytes, and 1024 megabytes (because computers, which use binary, are good with powers of two). Storage manufacturers use the latter, Windows uses the former. Linux and macOS typically use the former definition, too. To distinguish the two, "kibibyte" (abbreviated as KiB rather than KB) means 1024 bytes. There's unfortunately no term that exclusively refers to the 1000 byte definition. Neither definition of a kilobyte is wrong. All of this also applies to kilobytes, terabytes, and so on.

### GPU

This is the graphics processing unit. Most modern CPUs have one of these built in, commonly known as an iGPU, the i standing for integrated (as opposed to a dGPU, which is a separate dedicated card). This is most relevant to gaming, and is also used for machine learning, cryptocurrency mining, video editing, etc. If your GPU is especially weak, it may have trouble decoding high resolution video, but with modern computers, this isn't usually something you'll have to worry about.

### WiFi

802.11 is the technical name for WiFI. There are various versions of WiFi, with confusing names such as 802.11ac and 802.11n, but you probably won't need to check and compare them. Most devices support more than one standard.

Technical Terms, Jargon, and Other Gotcha's
-------------------------------------------

### Resolution

This is how many pixels a screen has. 1080p means a display 1,080 pixels high, typically with 1920x1080 pixels. 4K means 3840x2160, so it can also be called 2160p. You can also find laptops with 1366x768 and 1280x720 screens, but I wouldn't recommend going lower than that last one. 4K is probably overkill, but makes sense on larger screens, or if you're doing graphical design work.

### Display technologies

LED and LCD refer to the same technology, with the accurate name being an LCD display with LED backlight. OLED (and AMOLED) use a more sophisticated (and expensive!) technology that has much higher contrast. This is because it doesn't have a backlight like LCD displays do, so when something on the screen is supposed to be pure black, rather than being mostly dark, it's actually pure black, with the total absence of light. An LCD display can't achieve that level of darkness without being turned off entirely.

I've written more about LCD vs OLED display technologies [here](https://bune.city/2019/05/lynne-teaches-tech-dark-mode/).

### Optane

I've seen a few advertisements saying a laptop has "32gb of memory" and then clarifying that they mean "16gb ram, 16gb optane". Optane storage is essentially the same thing as an ssd, but faster. Those laptops have 16gb ram and 16gb of extremely fast storage (in addition to whatever hard drive or ssd it has).

### USB-C and Thunderbolt

USB-C refers to a particular type of USB port. It's not compatible with what we all call USB today, which is actually USB-A. (USB-B is mostly used for printers, so much so that many stores sell USB-A to -B connectors as "Printer cables".)

Thunderbolt is a standard that some USB-C ports support. A non-thunderbolt USB-C port does less than a thunderbolt one, mainly having no support for external displays.

You can read more about the differences between the various types and standards of USBs [here](https://bune.city/2019/05/lynne-teaches-tech-usb/).

### big.LITTLE architecture

This one's exclusive to smartphones.

A phone that uses this technology has two CPUs inside it, and the phone switches between them depending on battery level, performance, and so on. A phone with two quad-core CPUs using big.LITTLE will often be (technically correctly) marketed as an octo-core phone, even though it's impossible to have all eight of those cores active at once.

These are the main things to look out for. Thanks for reading!

